summaryrefslogtreecommitdiffstats
path: root/libavcodec/ivi.h
diff options
context:
space:
mode:
authorAlexandra Hájková <alexandra@khirnov.net>2016-04-18 10:49:08 +0200
committerDiego Biurrun <diego@biurrun.de>2016-12-03 14:36:03 +0100
commitc3defda0d80e19146e71c7adbdfd9c251f36d8bd (patch)
treedf9239a7d37613b37a45c247cd42d76ecfa37dc1 /libavcodec/ivi.h
parentf5b7bd2a7c3f3498119f7c4484962e15e8f2ad26 (diff)
downloadffmpeg-streaming-c3defda0d80e19146e71c7adbdfd9c251f36d8bd.zip
ffmpeg-streaming-c3defda0d80e19146e71c7adbdfd9c251f36d8bd.tar.gz
indeo: Convert to the new bitstream reader
Diffstat (limited to 'libavcodec/ivi.h')
-rw-r--r--libavcodec/ivi.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/libavcodec/ivi.h b/libavcodec/ivi.h
index 4082a90..bbc8842 100644
--- a/libavcodec/ivi.h
+++ b/libavcodec/ivi.h
@@ -29,10 +29,11 @@
#ifndef AVCODEC_IVI_H
#define AVCODEC_IVI_H
-#include "avcodec.h"
-#include "get_bits.h"
#include <stdint.h>
+#include "avcodec.h"
+#include "bitstream.h"
+
/**
* Indeo 4 frame types.
*/
@@ -210,7 +211,7 @@ typedef struct IVIPicConfig {
} IVIPicConfig;
typedef struct IVI45DecContext {
- GetBitContext gb;
+ BitstreamContext bc;
RVMapDesc rvmap_tabs[9]; ///< local corrected copy of the static rvmap tables
uint32_t frame_num;
@@ -302,14 +303,14 @@ void ff_ivi_init_static_vlc(void);
* Decode a huffman codebook descriptor from the bitstream
* and select specified huffman table.
*
* @param[in,out] gb the GetBit context
* @param[in] desc_coded flag signalling if table descriptor was coded
* @param[in] which_tab codebook purpose (IVI_MB_HUFF or IVI_BLK_HUFF)
* @param[out] huff_tab pointer to the descriptor of the selected table
* @param[in] avctx AVCodecContext pointer
* @return zero on success, negative value otherwise
*/
-int ff_ivi_dec_huff_desc(GetBitContext *gb, int desc_coded, int which_tab,
+int ff_ivi_dec_huff_desc(BitstreamContext *bc, int desc_coded, int which_tab,
IVIHuffTab *huff_tab, AVCodecContext *avctx);
/**
OpenPOWER on IntegriCloud
@@ -302,14 +303,14 @@ void ff_ivi_init_static_vlc(void);
* and select specified huffman table.
*
- * @param[in,out] gb the GetBit context
+ * @param[in,out] bc the Bitstream context
* @param[in] desc_coded flag signalling if table descriptor was coded
* @param[in] which_tab codebook purpose (IVI_MB_HUFF or IVI_BLK_HUFF)